Package io.github.evisentin.wordpress.client.adapter.apache.discovery


package io.github.evisentin.wordpress.client.adapter.apache.discovery
Internal infrastructure components responsible for WordPress REST API endpoint discovery using Apache HttpClient.

Classes in this package implement the WordPress discovery mechanism used to locate REST API endpoints from a site URL before client operations are executed.

This package is intended for internal use by the Apache HttpClient adapter and is not part of the library's public API.