Package io.github.evisentin.wordpress.client.adapter.apache.modules
package io.github.evisentin.wordpress.client.adapter.apache.modules
Apache HttpClient-based implementations of WordPress REST API modules.
This package contains concrete implementations of the domain API contracts defined in
io.github.evisentin.wordpress.client.domain.api. Each module is responsible for interacting with a specific
WordPress REST API endpoint and translating domain requests into HTTP requests executed through Apache
HttpClient.
The modules provide support for:
- CRUD operations for WordPress resources
- Pagination handling and response metadata extraction
- Query parameter mapping from domain query objects
- JSON serialization and deserialization using Jackson
- File uploads for media resources
All module implementations share common HTTP request execution logic provided by ApiClientModule.
-
ClassesClassDescriptionApache HttpClient implementation of
CategoryAPIs.Apache HttpClient implementation ofCommentAPIs.Apache HttpClient implementation ofMediaAPIs.Apache HttpClient implementation ofPostAPIs.Apache HttpClient implementation ofPostStatusAPIs.Apache HttpClient implementation ofPostTypeAPIs.Apache HttpClient implementation ofTagAPIs.