Package io.github.evisentin.wordpress.client.adapter.apache


package io.github.evisentin.wordpress.client.adapter.apache
Apache HttpClient-based adapter for the WordPress REST client.

This package contains the Apache HttpClient implementation of the client adapter layer, including the main ApacheWpRestClient and Apache-specific support classes used to execute authenticated requests against the WordPress REST API.

The classes in this package are responsible for translating high-level client operations into HTTP requests executed through Apache HttpClient.