Class WpAuthException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
io.github.evisentin.wordpress.client.domain.auth.WpAuthException
All Implemented Interfaces:
Serializable

public class WpAuthException extends RuntimeException
Runtime exception thrown when WordPress authentication fails or cannot be completed.
See Also:
  • Constructor Details

    • WpAuthException

      public WpAuthException(@NonNull @NonNull String message)
      Creates a new authentication exception with the specified detail message.
      Parameters:
      message - the detail message describing the authentication failure; must not be null
    • WpAuthException

      public WpAuthException(@NonNull @NonNull String message, @NonNull @NonNull Throwable cause)
      Creates a new authentication exception with the specified detail message and cause.
      Parameters:
      message - the detail message describing the authentication failure; must not be null
      cause - the underlying cause of the authentication failure; must not be null