Record Class WpBasicAuthenticationStrategy
java.lang.Object
java.lang.Record
io.github.evisentin.wordpress.client.domain.auth.WpBasicAuthenticationStrategy
- Record Components:
username- WordPress username; must not be blankpassword- WordPress password or application password; must not be blank
- All Implemented Interfaces:
WpAuthenticationStrategy
public record WpBasicAuthenticationStrategy(@NonNull String username, @NonNull String password)
extends Record
implements WpAuthenticationStrategy
Authentication strategy based on HTTP Basic Authentication.
-
Constructor Summary
ConstructorsConstructorDescriptionWpBasicAuthenticationStrategy(@NonNull String username, @NonNull String password) Creates an instance of aWpBasicAuthenticationStrategyrecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.@NonNull Stringpassword()Returns the value of thepasswordrecord component.final StringtoString()Returns a string representation of this record class.@NonNull Stringusername()Returns the value of theusernamerecord component.
-
Constructor Details
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
username
Returns the value of theusernamerecord component.- Returns:
- the value of the
usernamerecord component
-
password
Returns the value of thepasswordrecord component.- Returns:
- the value of the
passwordrecord component
-