Record Class WpJwtAuthenticationStrategy

java.lang.Object
java.lang.Record
io.github.evisentin.wordpress.client.domain.auth.WpJwtAuthenticationStrategy
Record Components:
username - WordPress username; must not be blank
password - WordPress password; must not be blank
jwtTokenEndPoint - endpoint for the JWT token, relative to API-URL; must not be blank
All Implemented Interfaces:
WpAuthenticationStrategy

public record WpJwtAuthenticationStrategy(@NonNull String username, @NonNull String password, @NonNull String jwtTokenEndPoint) extends Record implements WpAuthenticationStrategy
Authentication strategy based on JWT bearer token authentication.

Contains the credentials used to obtain a JWT token and the endpoint from which the token is requested.

  • Constructor Details

    • WpJwtAuthenticationStrategy

      public WpJwtAuthenticationStrategy(@NonNull @NonNull String username, @NonNull @NonNull String password, @NonNull @NonNull String jwtTokenEndPoint)
      Creates an instance of a WpJwtAuthenticationStrategy record class.
      Parameters:
      username - the value for the username record component
      password - the value for the password record component
      jwtTokenEndPoint - the value for the jwtTokenEndPoint record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • username

      @NonNull public @NonNull String username()
      Returns the value of the username record component.
      Returns:
      the value of the username record component
    • password

      @NonNull public @NonNull String password()
      Returns the value of the password record component.
      Returns:
      the value of the password record component
    • jwtTokenEndPoint

      @NonNull public @NonNull String jwtTokenEndPoint()
      Returns the value of the jwtTokenEndPoint record component.
      Returns:
      the value of the jwtTokenEndPoint record component