java.lang.Object
io.github.evisentin.wordpress.client.domain.configuration.SslConfiguration

public class SslConfiguration extends Object
Encapsulates SSL/TLS configuration to be applied to the underlying HTTP client.

This class allows advanced users to customize the SSL behaviour of the client, such as:

When provided to the client, all non-null components will be applied to the underlying HTTP client configuration.

Security note:
Misconfiguration of SSL components (e.g. trusting all certificates or disabling hostname verification) can expose the application to man-in-the-middle attacks. Such configurations should only be used in controlled environments (e.g. testing).

Instances of this class are immutable and can be safely reused.

  • Constructor Details

    • SslConfiguration

      public SslConfiguration()