Class WpForbiddenException

java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
io.github.evisentin.wordpress.client.domain.exception.WpForbiddenException
All Implemented Interfaces:
Serializable

public class WpForbiddenException extends RuntimeException
Exception thrown when the WordPress REST API returns a 403 Forbidden response.

This typically indicates that the request was understood, but the authenticated user does not have sufficient permissions to perform the requested operation.

See Also:
  • Constructor Details

    • WpForbiddenException

      public WpForbiddenException(WpError error)
      Creates a new exception for a 403 Forbidden response.
      Parameters:
      error - the error returned by the WordPress REST API