Uses of Class
io.github.evisentin.wordpress.client.domain.model.WpComment
Packages that use WpComment
Package
Description
Apache HttpClient-based adapter for the WordPress REST client.
Defines the operation contracts exposed by the WordPress REST client.
-
Uses of WpComment in io.github.evisentin.wordpress.client.adapter.apache
Methods in io.github.evisentin.wordpress.client.adapter.apache that return WpCommentModifier and TypeMethodDescriptionApacheWpRestClient.createComment(@NonNull WpCommentCreateUpdateRequest creationRequest) ApacheWpRestClient.getComment(long id, WpContext context) ApacheWpRestClient.getComment(long id, WpContext context, String password) ApacheWpRestClient.trashComment(long id) ApacheWpRestClient.updateComment(long id, @NonNull WpCommentCreateUpdateRequest updateRequest) Methods in io.github.evisentin.wordpress.client.adapter.apache that return types with arguments of type WpCommentModifier and TypeMethodDescriptionApacheWpRestClient.listComments(@NonNull WpPagingQuery pageQuery, WpCommentQuery commentQuery) -
Uses of WpComment in io.github.evisentin.wordpress.client.domain.api.operations
Methods in io.github.evisentin.wordpress.client.domain.api.operations that return WpCommentModifier and TypeMethodDescriptionCommentOperations.createComment(@NonNull WpCommentCreateUpdateRequest creationRequest) Creates a new comment.CommentOperations.getComment(long id, WpContext context) Retrieves a comment by its unique identifier using the given context.CommentOperations.getComment(long id, WpContext context, String password) Retrieves a comment by its unique identifier using the given context and optional password.CommentOperations.trashComment(long id) Moves a comment to the trash by its unique identifier.CommentOperations.updateComment(long id, @NonNull WpCommentCreateUpdateRequest updateRequest) Updates an existing comment.Methods in io.github.evisentin.wordpress.client.domain.api.operations that return types with arguments of type WpCommentModifier and TypeMethodDescriptionCommentOperations.listComments(@NonNull WpPagingQuery pageQuery, WpCommentQuery commentQuery) Retrieves a paginated list of comments using optional filtering and sorting criteria.