Uses of Package
io.github.evisentin.wordpress.client.domain.model
Packages that use io.github.evisentin.wordpress.client.domain.model
Package
Description
Apache HttpClient-based adapter for the WordPress REST client.
Apache HttpClient-based implementations of WordPress REST API modules.
Defines typed API contracts for interacting with WordPress REST API resources.
Contains exception types used by the WordPress REST client.
Data transfer objects (DTOs) representing WordPress resources.
-
Classes in io.github.evisentin.wordpress.client.domain.model used by io.github.evisentin.wordpress.client.adapter.apacheClassDescriptionRepresents a WordPress category as returned by the WordPress REST API.Represents a WordPress comment as returned by the WordPress REST API.Represents a WordPress media item as returned by the WordPress REST API.Represents a WordPress post as returned by the WordPress REST API.Represents a WordPress tag as returned by the WordPress REST API.Represents a WordPress post type as returned by the WordPress REST API.Represents a WordPress tag as returned by the WordPress REST API.
-
Classes in io.github.evisentin.wordpress.client.domain.model used by io.github.evisentin.wordpress.client.adapter.apache.modulesClassDescriptionRepresents a WordPress category as returned by the WordPress REST API.Represents a WordPress comment as returned by the WordPress REST API.Represents a WordPress media item as returned by the WordPress REST API.Generic wrapper representing a paginated response from the WordPress REST API.Represents a WordPress post as returned by the WordPress REST API.Represents a WordPress tag as returned by the WordPress REST API.Represents a WordPress post type as returned by the WordPress REST API.Represents a WordPress tag as returned by the WordPress REST API.
-
Classes in io.github.evisentin.wordpress.client.domain.model used by io.github.evisentin.wordpress.client.domain.apiClassDescriptionRepresents a WordPress category as returned by the WordPress REST API.Represents a WordPress comment as returned by the WordPress REST API.Represents a WordPress media item as returned by the WordPress REST API.Generic wrapper representing a paginated response from the WordPress REST API.Represents a WordPress post as returned by the WordPress REST API.Represents a WordPress tag as returned by the WordPress REST API.Represents a WordPress post type as returned by the WordPress REST API.Represents a WordPress tag as returned by the WordPress REST API.
-
-
Classes in io.github.evisentin.wordpress.client.domain.model used by io.github.evisentin.wordpress.client.domain.modelClassDescriptionBase class for WordPress content resources exposed through the WordPress REST API.