java.lang.Object
io.github.evisentin.wordpress.client.domain.model.query.WpCommentQuery

public class WpCommentQuery extends Object
Represents a query object for retrieving WordPress comments.

This model encapsulates the filtering, pagination, and sorting options supported by the WordPress Comments REST API endpoint.

Instances are immutable and should be created using the Builder.

See Also:
  • Constructor Details

    • WpCommentQuery

      public WpCommentQuery()