java.lang.Object
io.github.evisentin.wordpress.client.domain.model.query.WpPostQuery

public class WpPostQuery extends Object
Represents a query object for retrieving WordPress posts.

This class encapsulates filtering and sorting options supported by the WordPress posts endpoint.

Instances are immutable and should be created using the Builder.

  • Constructor Details

    • WpPostQuery

      public WpPostQuery()