Class WpPostRevisionQuery
java.lang.Object
io.github.evisentin.wordpress.client.domain.model.query.WpPostRevisionQuery
Represents a query object for retrieving WordPress post revisions.
This class encapsulates filtering and sorting options supported by the WordPress post revisions endpoint.
Instances are immutable and should be created using the Builder.
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
WpPostRevisionQuery
public WpPostRevisionQuery()
-