Class WpPostCreateUpdateRequest
java.lang.Object
io.github.evisentin.wordpress.client.domain.model.requests.WpPostCreateUpdateRequest
Request body used to create or update a WordPress post.
This model maps the JSON arguments accepted by the WordPress Posts REST API endpoint, including publication dates, slug, status, password, title, content, excerpt, author, featured media, discussion settings, post format, sticky flag, template, categories, and tags.
Null values are omitted during serialization.
- See Also:
-
Constructor Summary
Constructors -
Method Summary
-
Constructor Details
-
WpPostCreateUpdateRequest
public WpPostCreateUpdateRequest()
-