Interface WpRestClient
- All Known Implementing Classes:
ApacheWpRestClient,WpBaseRestClient
public interface WpRestClient
Main entry point for interacting with the WordPress REST API.
This interface aggregates operations for managing WordPress resources such as posts, categories, tags, and media items.
The client provides a strongly typed abstraction over the WordPress REST API, exposing high-level operations for creating, retrieving, updating, listing, trashing, and deleting resources.
Implementations are expected to communicate with the standard WordPress REST API endpoints under
/wp-json/wp/v2 or compatible APIs.
-
Method Summary
Modifier and TypeMethodDescriptionReturns the category API operations.comments()Returns the comment API operations.media()Returns the media API operations.Returns the page revisions API operations.pages()Returns the page API operations.Returns the post revisions API operations.posts()Returns the post API operations.Returns the post status API operations.Returns the post type API operations.search()Returns the search API operations.tags()Returns the tag API operations.Returns the taxonomy API operations.
-
Method Details
-
categories
CategoryAPIs categories()Returns the category API operations.- Returns:
- category API operations
-
comments
CommentAPIs comments()Returns the comment API operations.- Returns:
- comment API operations
-
media
MediaAPIs media()Returns the media API operations.- Returns:
- media API operations
-
pageRevisions
PageRevisionAPIs pageRevisions()Returns the page revisions API operations.- Returns:
- page revision API operations
-
pages
PageAPIs pages()Returns the page API operations.- Returns:
- page API operations
-
postRevisions
PostRevisionAPIs postRevisions()Returns the post revisions API operations.- Returns:
- post revision API operations
-
postStatuses
PostStatusAPIs postStatuses()Returns the post status API operations.- Returns:
- post status API operations
-
postTypes
PostTypeAPIs postTypes()Returns the post type API operations.- Returns:
- post type API operations
-
posts
PostAPIs posts()Returns the post API operations.- Returns:
- post API operations
-
search
SearchAPIs search()Returns the search API operations.- Returns:
- search API operations
-
tags
TagAPIs tags()Returns the tag API operations.- Returns:
- tag API operations
-
taxonomies
TaxonomyAPIs taxonomies()Returns the taxonomy API operations.- Returns:
- taxonomy API operations
-