Interface WpRestClient
- All Known Implementing Classes:
ApacheWpRestClient,WpBaseRestClient
public interface WpRestClient
Main entry point for interacting with the WordPress REST API.
This interface aggregates operations for managing WordPress resources such as posts, categories, tags, and media items.
The client provides a strongly typed abstraction over the WordPress REST API, exposing high-level operations for creating, retrieving, updating, listing, trashing, and deleting resources.
Implementations are expected to communicate with the standard WordPress REST API endpoints under
/wp-json/wp/v2 or compatible APIs.
-
Method Summary
Modifier and TypeMethodDescriptionReturns the category API operations.comments()Returns the comment API operations.media()Returns the media API operations.posts()Returns the post API operations.Returns the post status API operations.Returns the post type API operations.tags()Returns the tag API operations.
-
Method Details
-
categories
CategoryAPIs categories()Returns the category API operations.- Returns:
- category API operations
-
comments
CommentAPIs comments()Returns the comment API operations.- Returns:
- comment API operations
-
media
MediaAPIs media()Returns the media API operations.- Returns:
- media API operations
-
postStatuses
PostStatusAPIs postStatuses()Returns the post status API operations.- Returns:
- post status API operations
-
postTypes
PostTypeAPIs postTypes()Returns the post type API operations.- Returns:
- post type API operations
-
posts
PostAPIs posts()Returns the post API operations.- Returns:
- post API operations
-
tags
TagAPIs tags()Returns the tag API operations.- Returns:
- tag API operations
-