Package io.github.evisentin.wordpress.client.domain.api


package io.github.evisentin.wordpress.client.domain.api
Public API for interacting with the WordPress REST client.

This package defines the main client interfaces and base abstractions used to perform operations against the WordPress REST API.

Implementations of these interfaces are provided by adapter modules (e.g. Apache HttpClient, OkHttp).