Class WpAuthException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
io.github.evisentin.wordpress.client.domain.auth.WpAuthException
- All Implemented Interfaces:
Serializable
Runtime exception thrown when WordPress authentication fails or cannot be completed.
- See Also:
-
Constructor Summary
ConstructorsConstructorDescriptionWpAuthException(@NonNull String message) Creates a new authentication exception with the specified detail message.WpAuthException(@NonNull String message, @NonNull Throwable cause) Creates a new authentication exception with the specified detail message and cause. -
Method Summary
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
WpAuthException
Creates a new authentication exception with the specified detail message.- Parameters:
message- the detail message describing the authentication failure; must not benull
-
WpAuthException
Creates a new authentication exception with the specified detail message and cause.- Parameters:
message- the detail message describing the authentication failure; must not benullcause- the underlying cause of the authentication failure; must not benull
-